@@ -1,8 +1,8 @@
+use num_derive::FromPrimitive;
 use thiserror::Error;
+use solana_program::{decode_error::DecodeError, program_error::ProgramError};
 
-use solana_program::program_error::ProgramError;
-
-#[derive(Error, Debug, Copy, Clone)]
+#[derive(Error, Debug, Copy, Clone, FromPrimitive)]
 pub enum TokenWhitelistError {
     /// Invalid instruction
     #[error("Invalid Instruction")]
@@ -26,3 +26,9 @@ impl From<TokenWhitelistError> for ProgramError {
         ProgramError::Custom(e as u32)
     }
 }
+
+impl<T> DecodeError<T> for TokenWhitelistError {
+    fn type_of() -> &'static str {
+        "Token Whitelist Error"
+    }
+}
